<?php

class Product_Comments extends Module {
	private $maj = '';	
	
	function __construct() {
		$this->name = 'product_comments';
		$this->tab = 'Products';
		$this->version = 1.3;

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayName = '<font color="black">[EW]</font> ' . $this->l('Product\'s comments');
		$this->description = $this->l('Visitor can write and show comments on product page');
		
		// On regarde si one nouvelle version du module est disponible.
		if (!$this->checkUpdate()) {
			$this->displayName = '<font color="red">[!!]</font>' . $this->displayName;
			$this->description .= '<br /><br /><font color="red">'. $this->maj.'</font>';
		}
		
		$this->update(Configuration::get('EWPC_VERSION'));
	}

	public function update($from) {
		switch ($from) {
			case '1.3':
				// On ne change rien
				break;
			case '1.2':
				if (!Configuration::updateValue('EWPC_VERSION', 1.3))
					$this->warning = '<br/>'.$this->l('Unknown error in module [').__LINE__.$this->l(' - 1.2]. Please report it on PrestaShop forum.');
				break;
			default:
				if (!Configuration::updateValue('EWPC_VERSION', 1.3))
					$this->warning = '<br/>'.$this->l('Unknown error in module [').__LINE__.$this->l(' - 1.2]. Please report it on PrestaShop forum.');
				break;
		}
	}
	
	public function install() {
		if (!parent::install())
			return false;

		if (!$this->registerHook('productfooter'))
			return false;
			
		if (!$this->registerHook('productTab'))
			return false;
			
		if (!$this->registerHook('productTabContent'))
			return false;

		if (!Configuration::updateValue('EWPC_VERSION', 1.3))
			return false;
			
		if (!Configuration::updateValue('EWPC_EVALUATION_ENABLE', 0))
			return false;
			
		if (!Configuration::updateValue('EWPC_ANONYMOUS_ENABLE', 0))
			return false;
			
		if (!Configuration::updateValue('EWPC_NB_DEFAULTCOMMENTS', 0))
			return false;

		if (!Configuration::updateValue('EWPC_LANG_ALL', 1))
			return false;

		if (!Configuration::updateValue('EWPC_USERIDFORADMIN', ''))
			return false;

		if (!Configuration::updateValue('EWPC_TABENABLE', '1'))
			return false;

		$query = 'CREATE TABLE '._DB_PREFIX_.'product_comments (
				`id_comment` int(2) NOT NULL AUTO_INCREMENT,
				`id_customer` INT(2) NOT NULL,
				`name_customer` VARCHAR(255) NOT NULL,
				`id_product` INT(2) NOT NULL,
				`id_lang` INT(2) NOT NULL,
				`date` VARCHAR(255) NOT NULL,
				`evaluation` INT(2) NOT NULL,
				`comment` TEXT NOT NULL,
				PRIMARY KEY(`id_comment`)
			) ENGINE=MyISAM default CHARSET=utf8';
	 	if (!Db::getInstance()->Execute($query))
	 		return false;

		return true;
	}
	
    public function uninstall() {
	 	if (!parent::uninstall())
	 		return false;
	 	
	 	if (!Db::getInstance()->Execute('DROP TABLE '._DB_PREFIX_.'product_comments'))
	 		return false;
	 	
	 	if (!Configuration::deleteByName('EWPC_VERSION'))
	 		return false;
	 	
	 	if (!Configuration::deleteByName('EWPC_EVALUATION_ENABLE'))
	 		return false;

	 	if (!Configuration::deleteByName('EWPC_ANONYMOUS_ENABLE'))
	 		return false;
	 	
	 	if (!Configuration::deleteByName('EWPC_NB_DEFAULTCOMMENTS'))
	 		return false;
	 		
	 	if (!Configuration::deleteByName('EWPC_LANG_ALL'))
	 		return false;
	 		
	 	if (!Configuration::deleteByName('EWPC_USERIDFORADMIN'))
	 		return false;
	 		
	 	if (!Configuration::deleteByName('EWPC_TABENABLE'))
	 		return false;
	 	
	 	return true;
    }

    private function checkUpdate() {
    	$url = 'http://www.psfrance.org/checkmaj.php?site='.$_SERVER["HTTP_HOST"].'&module='.$this->name.'&version='.$this->version.'&ps_version='._PS_VERSION_;

    	if (!$content = @file_get_contents($url)) {
    		$this->maj = $this->l('Server not responding');
    		return true;
		}
    		
    	if ($content == 'MAJ:OK') {
    		$this->maj = $this->l('Module is up to date');
    		return true;
		}
    		
    	$errors = explode('|', $content);
    	foreach ($errors as $err) {
    		list($var, $value) = explode(':', $err);
    		
    		switch ($var) {
    			
    			case 'PSVERSION':
	     	 		$this->maj = $this->l('Your version of PrestaShop is to low for this module. Please upgrade!');
    				break;
    			
    			case 'VERSION':
    				$this->maj = $this->l('There are an upgrade for this module. Please upgrade!');
    				break;
    				
    			case 'ERROR':
    				if ($value == 'NOMODULESENDED')
    					$this->maj = $this->l('An unknow error is occured. Contact Pierre-Yves on www.PSFRANCE.org');
    				break;
    			
    			default:
    				$this->maj = $this->l('An unknow error is occured. Contact Pierre-Yves on www.PSFRANCE.org');
    				break;
    				
			}
		}
		
		return false;
	}
    
	public function getContent() {
		$output .= '<h2>'.$this->displayName.'</h2>';
		if (Tools::isSubmit('submitEWPC'))
		{
			$anonymous = Tools::getValue('anonymous');
			$lang = Tools::getValue('lang');
			$nbcomments = Tools::getValue('nbcomments');
			$adminid = Tools::getValue('adminid');
			$tabenable = Tools::getValue('tabenable');
			
			Configuration::updateValue('EWPC_ANONYMOUS_ENABLE', ($anonymous == 'on' ? 1 : 0));
			Configuration::updateValue('EWPC_LANG_ALL', ($lang == 'on' ? 1 : 0));
			Configuration::updateValue('EWPC_NB_DEFAULTCOMMENTS', intval($nbcomments));
			Configuration::updateValue('EWPC_USERIDFORADMIN', $adminid);
			Configuration::updateValue('EWPC_TABENABLE', ($tabenable == 'on' ? 1 : 0));
		}
		return $output.$this->displayForm();
	}

	private function displayForm() {
		
		$select_admin = '<option value="">'.$this->l('None').'</option>';
		$current_admin = Configuration::get('EWPC_USERIDFORADMIN');
		$temp = new Customer();
		$customers = $temp->getCustomers();
		
		foreach ($customers as $c) {
			$temp = new Customer($c['id_customer']);
			if ($temp->id == $current_admin)
				$select_admin .= '<option value="'.$temp->id.'" selected>'.$temp->lastname.' '.$temp->firstname.'</option>';
			else
				$select_admin .= '<option value="'.$temp->id.'">'.$temp->lastname.' '.$temp->firstname.'</option>';
		}
		
		$output = '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset><legend>'.$this->l('Settings').'</legend>
			
				<label>'.$this->l('Anonymous').'</label>
				<div class="margin-form">
					<input type="checkbox" name="anonymous" '.(Configuration::get('EWPC_ANONYMOUS_ENABLE') ? 'checked' : '').' />
					<p class="clear">'.$this->l('Accept or not anonymous post ? (not registered users)').'</p>
				</div>
				
				<label>'.$this->l('Language').'</label>
				<div class="margin-form">
					<input type="checkbox" name="lang" '.(Configuration::get('EWPC_LANG_ALL') ? 'checked' : '').' />
					<p class="clear">'.$this->l('Show all posts of any languages ?').'</p>
				</div>
				
				<label>'.$this->l('Number of comments').'</label>
				<div class="margin-form">
					<input style="width: 30px; text-align: center;" type="text" name="nbcomments" value="'.Configuration::get('EWPC_NB_DEFAULTCOMMENTS').'" />
					<p class="clear">'.$this->l('How many comments are displayed on the page in default?').'</p>
				</div>
				
				<label>'.$this->l('Admin').'</label>
				<div class="margin-form">
					<select name="adminid">'.$select_admin.'</select>
					<p class="clear">'.$this->l('Who can moderate (edit, delete, etc...) comments on product\'s page?').'</p>
				</div>
				
				<label>'.$this->l('Tab').'</label>
				<div class="margin-form">
					<input type="checkbox" name="tabenable" '.(Configuration::get('EWPC_TABENABLE') ? 'checked' : '').' />
					<p class="clear">'.$this->l('Display comments on tabbed with "More info" etc...').'</p>
				</div>
				
				<center><input type="submit" name="submitEWPC" value="'.$this->l('Save').'" class="button" /></center>
			</fieldset>
		</form>';
		return $output;
	}

	public function hookProductFooter($params) {
		$this->prepareForDisplay($params);
		return $this->display(__FILE__, 'product_comments.tpl');
	}
	
	public function hookproductTab($params) {
		if (Configuration::get('EWPC_TABENABLE') == 1)
			return $this->display(__FILE__, 'product_comments_tab.tpl');
		else
			return '';
	}
	
	public function hookproductTabContent($params) {
		if (Configuration::get('EWPC_TABENABLE') == 1) {
			return $this->display(__FILE__, 'product_comments_tab_content.tpl');
		}
		else
			return '';
	}
	
	private function getComments($id_product, $evaluation = false, $anonymous = false, $lang = 'all') {
	 	global $cookie;
	 	$result = array();
	 	$out = array();
	 	
	 	$query = 'SELECT * FROM '._DB_PREFIX_.'product_comments WHERE `id_product` = '.intval($id_product);
	 	if (!$anonymous)
	 		$query .= ' AND `id_customer` != 0';
	 	if ($lang != 'all')
	 		$query .= ' AND `id_lang` = '.intval($lang);
	 	$query .= ' ORDER BY `date`';
	 	
	 	if (!$out = Db::getInstance()->ExecuteS($query))
	 		return array();
	 	
	 	$i = 0;
	 	foreach ($out AS $comment) {
		 	$result[$i]['name_customer'] = $comment['name_customer'];
			$result[$i]['id_lang'] = $comment['id_lang'];
			$result[$i]['date'] = Tools::displayDate(date("Y-m-d H:i:s", $comment['date']), $cookie->__get('id_lang'));
			$result[$i]['evaluation'] = $comment['evaluation'];
			$result[$i]['comment'] = $comment['comment'];
			$result[$i]['id_comment'] = $comment['id_comment'];
			$i++;
		}		
	 	return $result;
	}
	
	private function processPOST($params) {
		if (!Configuration::get('EWPC_ANONYMOUS_ENABLE') && !$params['cart']->id_customer)
			return false;
		elseif (!Configuration::get('EWPC_ANONYMOUS_ENABLE') && isset($_POST['EWPC_form_anonymous']))
			return false;

		$id_customer = $params['cart']->id_customer;
		if (!$id_customer)
			$name_customer = $this->l('Anonymous');
		elseif ($_POST['EWPC_form_anonymous'] == 'on')
			$name_customer = $this->l('Anonymous');
		else
			$name_customer = $params['cookie']->customer_firstname.' '.strtoupper(substr($params['cookie']->customer_lastname, 0, 1)).'.';
		$id_product = $_GET['id_product'];
		$id_lang = $params['cookie']->id_lang;
		$evaluation = (isset($_POST['EWPC_form_evaluation']) ? intval($_POST['EWPC_form_evaluation']) : 0);
		$comment = $_POST['EWPC_form_comment'];
		
		$this->addComment($id_customer, $name_customer, $id_product, $id_lang, $evaluation, $comment);
	}
	
	private function addComment($id_customer, $name_customer, $id_product, $id_lang, $evaluation, $comment) {
		$query = 'INSERT INTO '._DB_PREFIX_.'product_comments VALUES (\'\', '.intval($id_customer).', \''.pSQL($name_customer).'\', '.intval($id_product).', '.intval($id_lang).',\''.time().'\' ,'.intval($evaluation).', \''.pSQL($comment).'\')';
	 	if (!Db::getInstance()->Execute($query) OR !$lastId = mysql_insert_id())
	 		return false;
	 	return true;
	}

	private function deleteComment($idcomment) {
		$query = 'DELETE FROM '._DB_PREFIX_.'product_comments WHERE `id_comment` = '.intval($idcomment);
	 	if (!Db::getInstance()->Execute($query))
	 		return false;
	 	return true;
	}
	
	private function prepareForDisplay($params) {
		global $smarty, $cookie;
		
		if (isset($_POST['EWPC_form_submit']))
			$this->processPOST($params);
		if (isset($_POST['EWPC_form_delete'])) {
			if (Configuration::get('EWPC_USERIDFORADMIN') == $params['cart']->id_customer)
				$this->deleteComment(Tools::getValue('commentid'));
		}
		
		$smarty->assign('EWPC_EVALUATION_ENABLE', Configuration::get('EWPC_EVALUATION_ENABLE'));
		$smarty->assign('EWPC_ANONYMOUS_ENABLE', Configuration::get('EWPC_ANONYMOUS_ENABLE'));
		$smarty->assign('EWPC_NB_DEFAULTCOMMENTS', Configuration::get('EWPC_NB_DEFAULTCOMMENTS'));
		$smarty->assign('EWPC_LANG_ALL', Configuration::get('EWPC_LANG_ALL'));
		$smarty->assign('EWPC_TABENABLE', Configuration::get('EWPC_TABENABLE'));

		$comments = $this->getComments($_GET['id_product'], false, (Configuration::get('EWPC_ANONYMOUS_ENABLE') ? true : false), (Configuration::get('EWPC_LANG_ALL') ? 'all' : $params['cookie']->id_lang));
		$smarty->assign('comments', $comments);
		$smarty->assign('nb_comments', count($comments));
		
		if (!$params['cart']->id_customer)
			$smarty->assign('user_isconnected', 0);
		else
			$smarty->assign('user_isconnected', 1);
		
		if (Configuration::get('EWPC_USERIDFORADMIN') == $params['cart']->id_customer)
			$smarty->assign('user_isadmin', 1);
		else
			$smarty->assign('user_isadmin', 0);
	}
}

?>